@@ -475,6 +475,9 @@ public:
 	///
 	void getLabelList(std::vector<docstring> &) const;
 
+	/// This removes the .aux and .bbl files from the temp dir.
+	void removeBiblioTempFiles() const;
+
 	///
 	void changeLanguage(Language const * from, Language const * to);
 
@@ -676,6 +679,8 @@ public:
 	int charCount(bool with_blanks) const;
 
 private:
+	///
+	void setMathFlavor(OutputParams & op) const;
 	/// Change name of buffer. Updates "read-only" flag.
 	void setFileName(support::FileName const & fname);
 	///
