@@ -62,6 +62,8 @@
 #include "insets/InsetRef.h"
 #include "insets/InsetText.h"
 
+#include "mathed/MathData.h"
+
 #include "frontends/alert.h"
 #include "frontends/Application.h"
 #include "frontends/Delegates.h"
@@ -684,6 +686,10 @@ Change const BufferView::getCurrentChange() const
 		return Change(Change::UNCHANGED);
 
 	DocIterator dit = d->cursor_.selectionBegin();
+	// The selected content might have been changed (see #7685)
+	while (dit.inMathed())
+		// Find enclosing text cursor
+		dit.pop_back();
 	return dit.paragraph().lookupChange(dit.pos());
 }
 
@@ -1170,17 +1176,6 @@ bool BufferView::getStatus(FuncRequest const & cmd, FuncStatus & flag)
 		break;
 	}
 
-	// FIXME We do not really want this here, but at present we need to
-	// handle their dispatch here, for reasons explained there, so we'll
-	// handle this here, too, for consistency.
-	case LFUN_BRANCH_ACTIVATE:
-	case LFUN_BRANCH_DEACTIVATE: {
-		BranchList const & branchList = buffer().params().branchlist();
-		docstring const branchName = cmd.argument();
-		flag.setEnabled(!branchName.empty() && branchList.find(branchName));
-		break;
-	}
-
 	default:
 		return false;
 	}
@@ -1935,40 +1930,6 @@ void BufferView::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 		break;
 	}
 
-	// FIXME We do not really want this here, but it has to be at present
-	// because we need a cursor for the recordUndoFullDocument call. What
-	// we would really like is a recordUndoBufferParams call that did not
-	// need a cursor, but we do not have that yet.
-	// So, if this does get fixed, this code can be moved back to Buffer.cpp,
-	// and the corresponding code in getStatus() should be moved back, too.
-	case LFUN_BRANCH_ACTIVATE:
-	case LFUN_BRANCH_DEACTIVATE: {
-		BranchList & branch_list = buffer().params().branchlist();
-		docstring const branch_name = cmd.argument();
-		// the case without a branch name is handled elsewhere
-		if (branch_name.empty()) {
-			dispatched = false;
-			break;
-		}
-		Branch * branch = branch_list.find(branch_name);
-		if (!branch) {
-			LYXERR0("Branch " << branch_name << " does not exist.");
-			dr.setError(true);
-			docstring const msg =
-				bformat(_("Branch \"%1$s\" does not exist."), branch_name);
-			dr.setMessage(msg);
-			break;
-		}
-		bool activate = cmd.action() == LFUN_BRANCH_ACTIVATE;
-		if (branch->isSelected() != activate) {
-			branch->setSelected(activate);
-			cur.recordUndoFullDocument();
-			dr.setError(false);
-			dr.screenUpdate(Update::Force);
-			dr.forceBufferUpdate();
-		}
-		break;
-	}
 
 	default:
 		// OK, so try the Buffer itself...
@@ -2501,7 +2462,8 @@ void BufferView::putSelectionAt(DocIterator const & cur,
 
 bool BufferView::selectIfEmpty(DocIterator & cur)
 {
-	if (!cur.paragraph().empty())
+	if ((cur.inTexted() && !cur.paragraph().empty())
+	    || (cur.inMathed() && !cur.cell().empty()))
 		return false;
 
 	pit_type const beg_pit = cur.pit();
