@@ -773,6 +773,14 @@ string const LaTeXFeatures::getPackages() const
 	if (mustProvide("setspace") && !tclass.provides("SetSpace"))
 		packages << "\\usepackage{setspace}\n";
 
+	// we need to assure that mhchem is loaded before esint
+	// because esint must be loaded AFTER amslatex and mhchem loads amlatex
+	// (this info is from the author of mhchem from June 2013)
+	if (mustProvide("mhchem") &&
+	    params_.use_mhchem != BufferParams::package_off)
+		packages << "\\PassOptionsToPackage{version=3}{mhchem}\n"
+			    "\\usepackage{mhchem}\n";
+
 	// esint must be after amsmath and wasysym, since it will redeclare
 	// inconsistent integral symbols
 	if (mustProvide("esint") &&
@@ -810,12 +818,6 @@ string const LaTeXFeatures::getPackages() const
 		packages << "\\PassOptionsToPackage{normalem}{ulem}\n"
 			    "\\usepackage{ulem}\n";
 
-	if (params_.use_mhchem == BufferParams::package_on ||
-	    (mustProvide("mhchem") &&
-	     params_.use_mhchem != BufferParams::package_off))
-		packages << "\\PassOptionsToPackage{version=3}{mhchem}\n"
-			    "\\usepackage{mhchem}\n";
-
 	if (mustProvide("nomencl")) {
 		// Make it work with the new and old version of the package,
 		// but don't use the compatibility option since it is
@@ -1388,7 +1390,8 @@ void LaTeXFeatures::getFloatDefinitions(odocstream & os) const
 			// effect. (Lgb)
 		}
 		if (cit->second)
-			os << "\n\\newsubfloat{" << from_ascii(fl.floattype()) << "}\n";
+			// The subfig package is loaded later
+			os << "\n\\AtBeginDocument{\\newsubfloat{" << from_ascii(fl.floattype()) << "}}\n";
 	}
 }
 
