@@ -3216,8 +3216,7 @@ int Paragraph::fixBiblio(Buffer const & buffer)
 		// these, which there should be.
 		// FIXME: why does it make sense to do that rather
 		// than keep the first? (JMarc)
-		Inset * inset = d->insetlist_.release(bibitem_pos);
-		eraseChar(bibitem_pos, track_changes);
+		Inset * inset = releaseInset(bibitem_pos);
 		d->insetlist_.begin()->inset = inset;
 		return -bibitem_pos;
 	}
@@ -3305,7 +3304,9 @@ void Paragraph::changeCase(BufferParams const & bparams, pos_type pos,
 	// process sequences of modified characters; in change
 	// tracking mode, this approach results in much better
 	// usability than changing case on a char-by-char basis
-	docstring changes;
+	// We also need to track the current font, since font
+	// changes within sequences can occur.
+	vector<pair<char_type, Font> > changes;
 
 	bool const trackChanges = bparams.trackChanges;
 
@@ -3339,7 +3340,7 @@ void Paragraph::changeCase(BufferParams const & bparams, pos_type pos,
 		}
 
 		if (oldChar != newChar) {
-			changes += newChar;
+			changes.push_back(make_pair(newChar, getFontSettings(bparams, pos)));
 			if (pos != right - 1)
 				continue;
 			// step behind the changing area
@@ -3348,9 +3349,8 @@ void Paragraph::changeCase(BufferParams const & bparams, pos_type pos,
 
 		int erasePos = pos - changes.size();
 		for (size_t i = 0; i < changes.size(); i++) {
-			insertChar(pos, changes[i],
-				   getFontSettings(bparams,
-						   erasePos),
+			insertChar(pos, changes[i].first,
+				   changes[i].second,
 				   trackChanges);
 			if (!eraseChar(erasePos, trackChanges)) {
 				++erasePos;
