@@ -1033,7 +1033,14 @@ bool GuiApplication::getStatus(FuncRequest const & cmd, FuncStatus & flag) const
 	case LFUN_SERVER_NOTIFY:
 		enable = true;
 		break;
-
+ 
+	case LFUN_DIALOG_SHOW: {
+		string const name = cmd.getArg(0);
+		if (name == "aboutlyx" || name == "prefs") {
+			return true;
+		}
+	}
+ 
 	default:
 		return false;
 	}
@@ -1460,7 +1467,18 @@ void GuiApplication::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 		}
 
 		actOnUpdatedPrefs(lyxrc_orig, lyxrc);
-		resetGui();
+
+		// If the request comes from the minibuffer, then we can't reset
+		// the GUI, since that would destory the minibuffer itself and
+		// cause a crash, since we are currently in one of the methods of 
+		// GuiCommandBuffer. See bug #8540. 
+		if (cmd.origin() != FuncRequest::COMMANDBUFFER)
+			resetGui();
+		// else
+		//   FIXME Unfortunately, that leaves a bug here, since we cannot
+		//   reset the GUI in this case. If the changes to lyxrc affected the
+		//   UI, then, nothing would happen. This seems fairly unlikely, but 
+		//   it definitely is a bug.
 
 		break;
 	}
@@ -1634,6 +1652,15 @@ void GuiApplication::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 		lyxerr.setLevel(Debug::value(to_utf8(cmd.argument())));
 		break;
 
+	case LFUN_DIALOG_SHOW: {
+		string const name = cmd.getArg(0);
+
+		if ( name == "aboutlyx" || name == "prefs") {
+			if (current_view_ == 0)
+				createView();
+		}
+	}
+
 	default:
 		// The LFUN must be for one of GuiView, BufferView, Buffer or Cursor;
 		// let's try that:
