@@ -940,7 +940,7 @@ void GuiWorkArea::generateSyntheticMouseEvent()
 		buffer_view_->scroll(up ? -step : step);
 		buffer_view_->updateMetrics();
 	} else {
-		buffer_view_->scrollDocView(value + up ? -step : step, false);
+		buffer_view_->scrollDocView(value + (up ? -step : step), false);
 	}
 
 	// In which paragraph do we have to set the cursor ?
@@ -1907,7 +1907,7 @@ void TabWorkArea::updateTabTexts()
 	for (It it = paths.begin(); it != paths.end(); ++it) {
 		int const tab_index = it->tab();
 		Buffer const & buf = workArea(tab_index)->bufferView().buffer();
-		QString tab_text = it->displayString();
+		QString tab_text = it->displayString().replace("&", "&&");
 		if (!buf.fileName().empty() && !buf.isClean())
 			tab_text += "*";
 		setTabText(tab_index, tab_text);
