@@ -1355,6 +1355,7 @@ void MenuDefinition::expandBranches(Buffer const * buf)
 	BufferParams const & master_params = buf->masterBuffer()->params();
 	BufferParams const & params = buf->params();
 	if (params.branchlist().empty() && master_params.branchlist().empty() ) {
+		LYXERR(Debug::GUI, "No Branches set for Document");
 		add(MenuItem(MenuItem::Help, qt_("No Branches Set for Document!")));
 		return;
 	}
@@ -1368,6 +1369,7 @@ void MenuDefinition::expandBranches(Buffer const * buf)
 			label = convert<docstring>(ii) + ". " + label
 				+ char_type('|') + convert<docstring>(ii);
 		}
+		LYXERR(Debug::GUI, "Add item for branch " << label);
 		addWithStatusCheck(MenuItem(MenuItem::Command, toqstr(label),
 				    FuncRequest(LFUN_BRANCH_INSERT,
 						cit->branch())));
@@ -1724,7 +1726,7 @@ void Menus::Impl::macxMenuBarInit(GuiView * view, QMenuBar * qmb)
 		QAction::MenuRole role;
 	};
 
-	MacMenuEntry entries[] = {
+	static MacMenuEntry entries[] = {
 		{LFUN_DIALOG_SHOW, "aboutlyx", "About LyX",
 		 QAction::AboutRole},
 		{LFUN_DIALOG_SHOW, "prefs", "Preferences",
@@ -1737,6 +1739,7 @@ void Menus::Impl::macxMenuBarInit(GuiView * view, QMenuBar * qmb)
 
 	// the special menu for Menus. Fill it up only once.
 	if (mac_special_menu_.size() == 0) {
+		LYXERR(Debug::GUI, "Prepare Mac OS X special menu");
 		for (size_t i = 0 ; i < num_entries ; ++i) {
 			FuncRequest const func(entries[i].action,
 				from_utf8(entries[i].arg));
@@ -1744,7 +1747,6 @@ void Menus::Impl::macxMenuBarInit(GuiView * view, QMenuBar * qmb)
 				entries[i].label, func));
 		}
 	}
-	
 	// add the entries to a QMenu that will eventually be empty
 	// and therefore invisible.
 	QMenu * qMenu = qmb->addMenu("special");
@@ -1755,6 +1757,7 @@ void Menus::Impl::macxMenuBarInit(GuiView * view, QMenuBar * qmb)
 			cit->func(), QString(), qMenu);
 		action->setMenuRole(entries[i].role);
 		qMenu->addAction(action);
+		LYXERR(Debug::GUI, "Add special menu item " << cit->label());
 	}
 }
 
