@@ -152,7 +152,7 @@ bool TocWidget::getStatus(Cursor & cur, FuncRequest const & cmd,
 	case LFUN_OUTLINE_IN:
 	case LFUN_OUTLINE_OUT:
 	case LFUN_SECTION_SELECT:
-		status.setEnabled(true);
+		status.setEnabled(item.dit() != 0);
 		return true;
 
 	case LFUN_LABEL_COPY_AS_REF: {
@@ -187,9 +187,16 @@ void TocWidget::doDispatch(Cursor & cur, FuncRequest const & cmd)
 	{
 	case LFUN_CHANGE_ACCEPT:
 	case LFUN_CHANGE_REJECT:
+		dispatch(item.action());
+		cur.dispatch(tmpcmd);
+		break;
+
 	case LFUN_SECTION_SELECT:
 		dispatch(item.action());
 		cur.dispatch(tmpcmd);
+		// necessary to get the selection drawn.
+		cur.buffer()->changed(true);
+		gui_view_.setFocus();
 		break;
 
 	case LFUN_LABEL_COPY_AS_REF: {
