@@ -57,14 +57,17 @@ namespace os = support::os;
 InsetBibtex::InsetBibtex(Buffer * buf, InsetCommandParams const & p)
 	: InsetCommand(buf, p)
 {
-	buffer().invalidateBibfileCache();
+	buffer().invalidateBibinfoCache();
+	buffer().removeBiblioTempFiles();
 }
 
 
 InsetBibtex::~InsetBibtex()
 {
-	if (isBufferLoaded())
+	if (isBufferLoaded()) {
 		buffer().invalidateBibfileCache();
+		buffer().removeBiblioTempFiles();
+	}
 }
 
 
@@ -107,6 +110,7 @@ void InsetBibtex::doDispatch(Cursor & cur, FuncRequest & cmd)
 		cur.recordUndo();
 		setParams(p);
 		buffer().invalidateBibfileCache();
+		buffer().removeBiblioTempFiles();
 		cur.forceBufferUpdate();
 		break;
 	}
@@ -952,16 +956,17 @@ docstring InsetBibtex::xhtml(XHTMLStream & xs, OutputParams const &) const
 		xs << html::StartTag("div", "class='bibtexentry'");
 		// FIXME XHTML
 		// The same name/id problem we have elsewhere.
-		string const attr = "id='LyXCite-" + to_utf8(entry.key()) + "'";
+		string const attr = "id='LyXCite-" + 
+				to_utf8(html::cleanAttr(entry.key())) + "'";
 		xs << html::CompTag("a", attr);
 		docstring citekey;
 		if (numbers)
 			citekey = entry.citeNumber();
 		else {
-			docstring const auth = entry.getAbbreviatedAuthor();
+			docstring const auth = entry.getAbbreviatedAuthor(buffer());
 			// we do it this way so as to access the xref, if necessary
 			// note that this also gives us the modifier
-			docstring const year = bibinfo.getYear(*vit, true);
+			docstring const year = bibinfo.getYear(*vit, buffer(), true);
 			if (!auth.empty() && !year.empty())
 				citekey = auth + ' ' + year;
 		}
