@@ -44,7 +44,16 @@ ParamInfo InsetCitation::param_info_;
 
 InsetCitation::InsetCitation(Buffer * buf, InsetCommandParams const & p)
 	: InsetCommand(buf, p)
-{}
+{
+	buffer().removeBiblioTempFiles();
+}
+
+
+InsetCitation::~InsetCitation()
+{
+	if (isBufferLoaded())
+		buffer().removeBiblioTempFiles();
+}
 
 
 ParamInfo const & InsetCitation::findInfo(string const & /* cmdName */)
@@ -103,8 +112,10 @@ bool InsetCitation::isCompatibleCommand(string const & cmd)
 
 void InsetCitation::doDispatch(Cursor & cur, FuncRequest & cmd)
 {
-	if (cmd.action() == LFUN_INSET_MODIFY)
+	if (cmd.action() == LFUN_INSET_MODIFY) {
+		buffer().removeBiblioTempFiles();
 		cache.recalculate = true;
+	}
 	InsetCommand::doDispatch(cur, cmd);
 }
 
@@ -217,7 +228,7 @@ inline docstring wrapCitation(docstring const & key,
 		return content;
 	// we have to do the escaping here, because we will ultimately
 	// write this as a raw string, so as not to escape the tags.
-	return "<a href='#" + key + "'>" +
+	return "<a href='#LyXCite-" + html::cleanAttr(key) + "'>" +
 			html::htmlize(content, XHTMLStream::ESCAPE_ALL) + "</a>";
 }
 
@@ -321,8 +332,8 @@ docstring InsetCitation::complexLabel(bool for_xhtml) const
 	vector<docstring>::const_iterator end = keys.end();
 	for (; it != end; ++it) {
 		// get the bibdata corresponding to the key
-		docstring const author = biblist.getAbbreviatedAuthor(*it);
-		docstring const year = biblist.getYear(*it, for_xhtml);
+		docstring const author = biblist.getAbbreviatedAuthor(*it, buffer());
+		docstring const year = biblist.getYear(*it, buffer(), for_xhtml);
 		docstring const citenum = for_xhtml ? biblist.getCiteNumber(*it) : *it;
 
 		if (author.empty() || year.empty())
