@@ -412,57 +412,54 @@ bool findPreviousChange(BufferView * bv)
 
 bool findChange(BufferView * bv, bool next)
 {
-	if (bv->cursor().selection()) {
-		// set the cursor at the beginning or at the end of the selection
-		// before searching. Otherwise, the current change will be found.
-		if (next != (bv->cursor().top() > bv->cursor().normalAnchor()))
-			bv->cursor().setCursorToAnchor();
-	}
-
-	DocIterator cur = bv->cursor();
+	Cursor cur(*bv);
+	cur.setCursor(next ? bv->cursor().selectionEnd()
+		      : bv->cursor().selectionBegin());
 
 	// Are we within a change ? Then first search forward (backward),
 	// clear the selection and search the other way around (see the end
 	// of this function). This will avoid changes to be selected half.
 	bool search_both_sides = false;
-	DocIterator tmpcur = cur;
-	// Leave math first
+	Cursor tmpcur = cur;
+	// Find enclosing text cursor
 	while (tmpcur.inMathed())
 		tmpcur.pop_back();
 	Change change_next_pos
 		= tmpcur.paragraph().lookupChange(tmpcur.pos());
-	if (change_next_pos.changed() && cur.inMathed()) {
-		cur = tmpcur;
-		search_both_sides = true;
-	} else if (tmpcur.pos() > 0 && tmpcur.inTexted()) {
-		Change change_prev_pos
-			= tmpcur.paragraph().lookupChange(tmpcur.pos() - 1);
-		if (change_next_pos.isSimilarTo(change_prev_pos))
+	if (change_next_pos.changed()) {
+		if (cur.inMathed()) {
+			cur = tmpcur;
 			search_both_sides = true;
+		} else if (tmpcur.pos() > 0 && tmpcur.inTexted()) {
+			Change change_prev_pos
+				= tmpcur.paragraph().lookupChange(tmpcur.pos() - 1);
+			if (change_next_pos.isSimilarTo(change_prev_pos))
+				search_both_sides = true;
+		}
 	}
 
+	// find the next change
 	if (!findChange(cur, next))
 		return false;
 
-	bv->cursor().setCursor(cur);
-	bv->cursor().resetAnchor();
+	bv->mouseSetCursor(cur, false);
 
 	CursorSlice & tip = cur.top();
 
-	if (!next)
+	if (!next && tip.pos() > 0)
 		// take a step into the change
 		tip.backwardPos();
 
 	Change orig_change = tip.paragraph().lookupChange(tip.pos());
 
 	if (next) {
-		for (; !tip.at_end(); tip.forwardPos()) {
+		for (; tip.pit() < tip.lastpit() || tip.pos() < tip.lastpos(); tip.forwardPos()) {
 			Change change = tip.paragraph().lookupChange(tip.pos());
 			if (!change.isSimilarTo(orig_change))
 				break;
 		}
 	} else {
-		for (; !tip.at_begin();) {
+		for (; tip.pit() > 0 || tip.pos() > 0;) {
 			tip.backwardPos();
 			Change change = tip.paragraph().lookupChange(tip.pos());
 			if (!change.isSimilarTo(orig_change)) {
@@ -473,12 +470,11 @@ bool findChange(BufferView * bv, bool next)
 		}
 	}
 
-	// Now put cursor to end of selection:
-	bv->cursor().setCursor(cur);
-	bv->cursor().setSelection();
-
-	if (search_both_sides) {
-		bv->cursor().setSelection(false);
+	if (!search_both_sides) {
+		// Now set the selection.
+		bv->mouseSetCursor(cur, true);
+	} else {
+		bv->mouseSetCursor(cur, false);
 		findChange(bv, !next);
 	}
 
@@ -566,27 +562,6 @@ string apply_escapes(string s, Escapes const & escape_map)
 	return s;
 }
 
-/** Return the position of the closing brace matching the open one at s[pos],
- ** or s.size() if not found.
- **/
-static size_t find_matching_brace(string const & s, size_t pos)
-{
-	LASSERT(s[pos] == '{', /* */);
-	int open_braces = 1;
-	for (++pos; pos < s.size(); ++pos) {
-		if (s[pos] == '\\')
-			++pos;
-		else if (s[pos] == '{')
-			++open_braces;
-		else if (s[pos] == '}') {
-			--open_braces;
-			if (open_braces == 0)
-				return pos;
-		}
-	}
-	return s.size();
-}
-
 /// Within \regexp{} apply get_lyx_unescapes() only (i.e., preserve regexp semantics of the string),
 /// while outside apply get_lyx_unescapes()+get_regexp_escapes().
 /// If match_latex is true, then apply regexp_latex_escapes() to \regexp{} contents as well.
