@@ -684,7 +684,8 @@ ParagraphList::const_iterator makeParagraphs(Buffer const & buf,
 	for (; par != pend; ++par) {
 		Layout const & lay = par->layout();
 		if (!lay.counter.empty())
-			buf.params().documentClass().counters().step(lay.counter, OutputUpdate);
+			buf.masterBuffer()->params().
+			    documentClass().counters().step(lay.counter, OutputUpdate);
 		// FIXME We should see if there's a label to be output and
 		// do something with it.
 		if (par != pbegin)
@@ -778,7 +779,7 @@ ParagraphList::const_iterator makeEnvironmentHtml(Buffer const & buf,
 		// FIXME There may be a bug here about user defined enumeration
 		// types. If so, then we'll need to take the counter and add "i",
 		// "ii", etc, as with enum.
-		Counters & cnts = buf.params().documentClass().counters();
+		Counters & cnts = buf.masterBuffer()->params().documentClass().counters();
 		docstring const & cntr = style.counter;
 		if (!style.counter.empty() 
 		    && (par == pbegin || !isNormalEnv(style)) 
@@ -902,7 +903,8 @@ void makeCommand(Buffer const & buf,
 {
 	Layout const & style = pbegin->layout();
 	if (!style.counter.empty())
-		buf.params().documentClass().counters().step(style.counter, OutputUpdate);
+		buf.masterBuffer()->params().
+		    documentClass().counters().step(style.counter, OutputUpdate);
 
 	openTag(xs, style, pbegin->params());
 
@@ -947,11 +949,15 @@ void xhtmlParagraphs(Text const & text,
 	while (bpit < epit) {
 		ParagraphList::const_iterator par = paragraphs.constIterator(bpit);
 		if (par->params().startOfAppendix()) {
-			// FIXME: only the counter corresponding to toplevel
-			// sectioning should be reset
-			Counters & cnts = buf.masterBuffer()->params().documentClass().counters();
-			cnts.reset();
-			cnts.appendix(true);
+			// We want to reset the counter corresponding to toplevel sectioning
+			Layout const & lay =
+				buf.masterBuffer()->params().documentClass().getTOCLayout();
+			docstring const cnt = lay.counter;
+			if (!cnt.empty()) {
+				Counters & cnts =
+					buf.masterBuffer()->params().documentClass().counters();
+				cnts.reset(cnt);
+			}
 		}
 		Layout const & style = par->layout();
 		ParagraphList::const_iterator const lastpar = par;
