@@ -285,9 +285,6 @@ docstring const getStringFromVector(std::vector<docstring> const & vec,
 /// found, else -1. The last item in \p str must be "".
 int findToken(char const * const str[], std::string const & search_token);
 
-/// A test string that is supposed to be translated into the gettext code
-std::string const languageTestString();
-
 template <class Arg1>
 docstring bformat(docstring const & fmt, Arg1);
 
