@@ -39,8 +39,12 @@ public:
 	///
 	std::string notefontcolor() const { return h_notefontcolor; }
 	///
+	std::string language() const { return h_language; }
+	///
 	std::string use_indices() const { return h_use_indices; }
 	///
+	std::string polyglossia2lyx(std::string const & language);
+	///
 	bool indentParagraphs() const;
 	///
 	bool isPackageUsed(std::string const & package) const;
@@ -64,13 +68,17 @@ public:
 	/// Get author named \p name (must be registered first)
 	Author const & getAuthor(std::string const & name) const;
 
-
 	/// Parses the LaTeX preamble into internal data
 	void parse(Parser & p, std::string const & forceclass,
 	           TeX2LyXDocClass & tc);
 	/// Writes the LyX file header from internal data
 	bool writeLyXHeader(std::ostream & os, bool subdoc);
 
+	/// known polyglossia language names (including variants)
+	static const char * const polyglossia_languages[];
+	/// the same as polyglossia_languages with .lyx names
+	static const char * const coded_polyglossia_languages[];
+
 private:
 	///
 	std::map<std::string, std::vector<std::string> > used_packages;
@@ -103,6 +111,7 @@ private:
 	std::string h_font_sf_scale;
 	std::string h_font_tt_scale;
 	std::string h_graphics;
+	std::string h_default_output_format;
 	std::string h_html_be_strict;
 	std::string h_html_css_as_file;
 	std::string h_html_math_output;
@@ -114,6 +123,8 @@ private:
 	std::string h_notefontcolor;
 	std::string h_options;
 	std::string h_output_changes;
+	std::string h_output_sync;
+	std::string h_output_sync_macro;
 	std::string h_papercolumns;
 	std::string h_paperfontsize;
 	std::string h_paperorientation;
